﻿import matplotlib.pyplot as plt
import numpy as np

# Valeurs experimentales
x=np.array([0.01,0.41,0.91,1.39,1.86,2.33,2.81,3.33,3.79,4.31,4.83,5.36,5.86,6.34,6.77])
z=np.array([0.01,0.52,1.01,1.42,1.77,2.02,2.16,2.19,2.13,1.96,1.71,1.38,0.97,0.50,0])
t=0.1*np.arange(len(x)) # on définit une base de temps de la même taille que les tableaux de mesures (ici selon ux)
# avec un espacement des valeurs temporelles de 0.1s

# Les coordonnées du vecteur vitesse
def calcul_vitesses(abscisses,ordonnees,temps):
    v_x=[]
    v_y=[]
    for n in range(len(abscisses)-1):
        v_x.append((abscisses[n+1]-abscisses[n])/(temps[n+1]-temps[n]))
        v_y.append((ordonnees[n+1]-ordonnees[n])/(temps[n+1]-temps[n]))
    temps=temps[:-1]
    return v_x,v_y,temps

# Paramétrage des graphes
def representation_graphique(abscisses,ordonnees,v_x,v_y):
    plt.figure(figsize=(10,3))
    plt.subplots_adjust(left=0.06, bottom=0.16, right=0.99, top=0.92,
                wspace=0.2, hspace=None)
    #------------------------------
    plt.subplot(1,3,1)
    plt.scatter(abscisses,ordonnees,marker='+')
    plt.title('Vecteur vitesse instantanée')
    plt.xlabel('x en (m)')
    plt.ylabel('Altitude z en (m)')
    plt.xlim(0.8*min(abscisses),1.2*max(abscisses))

# Tracé du vecteur vitesse
    for i in range(0,len(v_x),1):
        V=plt.quiver(abscisses[i], ordonnees[i] ,v_x[i] , v_y[i],
         scale_units='xy',angles='xy', scale=12)
        plt.quiverkey(V,0.8,0.8,500,label='v')
    #------------------------------
    plt.subplot(1,3,2)
    plt.scatter(abscisses,ordonnees,marker='+')
    plt.title('Variation du vecteur vitesse')
    plt.xlabel('x en (m)')
    plt.ylabel('Altitude z en (m)')
    plt.xlim(0.8*min(abscisses),1.2*max(abscisses))

# Tracé du vecteur variation de vitesse
    for i in range(1,len(v_x)-1,1):
        DV=plt.quiver(abscisses[i],ordonnees[i], ... , ... ,
        scale_units='xy',angles='xy', scale=2, color='red')
        plt.quiverkey(DV,0.8,0.8,100,label='V(n+1)-V(n)', labelcolor='red')
    #-------------------------------

    plt.show()

#Le programme principal--------------------------------------------



v_x,v_y,temps_v=calcul_vitesses(x,z,t)
representation_graphique(x,z,v_x,v_y)
